@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Simple box operations */
 
 /* 
@@ -705,6 +707,25 @@ meta_rectangle_contained_in_region (const GList         *spanning_rects,
   return contained;
 }
 
+gboolean
+meta_rectangle_overlaps_with_region (const GList         *spanning_rects,
+                                     const MetaRectangle *rect)
+{
+  const GList *temp;
+  gboolean     overlaps;
+
+  temp = spanning_rects;
+  overlaps = FALSE;
+  while (!overlaps && temp != NULL)
+    {
+      overlaps = overlaps || meta_rectangle_overlap (temp->data, rect);
+      temp = temp->next;
+    }
+
+  return overlaps;
+}
+
+
 void
 meta_rectangle_clamp_to_fit_into_region (const GList         *spanning_rects,
                                          FixedDirections      fixed_directions,
@@ -1226,6 +1247,7 @@ meta_rectangle_edge_cmp_ignore_type (gconstpointer a, gconstpointer b)
 {
   const MetaEdge *a_edge_rect = (gconstpointer) a;
   const MetaEdge *b_edge_rect = (gconstpointer) b;
+  int a_compare, b_compare;
 
   /* Edges must be both vertical or both horizontal, or it doesn't make
    * sense to compare them.
@@ -1233,8 +1255,6 @@ meta_rectangle_edge_cmp_ignore_type (gconstpointer a, gconstpointer b)
   g_assert ((a_edge_rect->rect.width  == 0 && b_edge_rect->rect.width == 0) ||
             (a_edge_rect->rect.height == 0 && b_edge_rect->rect.height == 0));
 
-  int a_compare, b_compare;
-
   a_compare = b_compare = 0;  /* gcc-3.4.2 sucks at figuring initialized'ness */
 
   if (a_edge_rect->side_type == META_DIRECTION_LEFT ||
