@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity X managed windows */
 
 /* 
@@ -123,8 +125,11 @@ struct _MetaWindow
   /* Whether we're maximized */
   guint maximized_horizontally : 1;
   guint maximized_vertically : 1;
+
+  /* Whether we have to maximize/minimize after placement */
   guint maximize_horizontally_after_placement : 1;
   guint maximize_vertically_after_placement : 1;
+  guint minimize_after_placement : 1;
 
   /* Whether we're shaded */
   guint shaded : 1;
@@ -575,6 +580,7 @@ MetaWindow* meta_window_find_root_ancestor    (MetaWindow *window);
 
 void meta_window_begin_grab_op (MetaWindow *window,
                                 MetaGrabOp  op,
+                                gboolean    frame_action,
                                 guint32     timestamp);
 
 void meta_window_update_keyboard_resize (MetaWindow *window,
@@ -602,4 +608,7 @@ void meta_window_set_user_time (MetaWindow *window,
 void meta_window_set_demands_attention (MetaWindow *window);
 
 void meta_window_unset_demands_attention (MetaWindow *window);
+
+void meta_window_update_icon_now (MetaWindow *window);
+
 #endif
